#
# spec file for package python-django-minio-storage
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with test
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-django-minio-storage
Version:        0.5.3
Release:        3.1
Summary:        Django file storage using minio
License:        Apache-2.0 OR MIT
URL:            https://github.com/py-pa/django-minio-storage
Source:         https://files.pythonhosted.org/packages/source/d/django-minio-storage/django-minio-storage-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-minio >= 7
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module minio >= 7}
BuildRequires:  %{python_module pytest-django >= 3.5.1}
BuildRequires:  %{python_module pytest-pythonpath}
BuildRequires:  %{python_module requests}
BuildRequires:  minio
%endif
%python_subpackages

%description
Django file storage using the minio python client.

%prep
%setup -q -n django-minio-storage-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
export MINIO_ACCESS_KEY=weak_access_key
export MINIO_SECRET_KEY=weak_secret_key
rm -rf $HOME/minio_export
mkdir $HOME/minio_export
/usr/sbin/minio server $HOME/minio_export &

export MINIO_STORAGE_ENDPOINT=localhost:9000
export MINIO_STORAGE_ACCESS_KEY=$MINIO_ACCESS_KEY
export MINIO_STORAGE_SECRET_KEY=$MINIO_SECRET_KEY
%pytest -rs
%endif

%files %{python_files}
%doc README.md docs/usage.md
%license LICENSE-APACHE LICENSE-MIT
%{python_sitelib}/minio_storage
%{python_sitelib}/django_minio_storage-%{version}.dist-info

%changelog
* Tue Jun  3 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.3:
  * This is an package metadata only update.
* Sun May  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.2:
  * Add/fix more type hints.
  * Fix type hints
* Sun Apr 23 2023 Dirk Müller <dmueller@suse.com>
- update to 0.5.0:
  * Switched the minio-py client library version from `<7` to
    `>=7`.
  * Minimum Django version is now 3.2
  * Minimum Python version is now 3.8
* Tue Dec 22 2020 John Vandenberg <jayvdb@gmail.com>
- Fix disabled test invocation
- Update to v0.3.10
  * Pin minio version to < 7
- from v0.3.9
  * The minio client is now deconstructable by Django, fixes migrations.
- from v0.3.8
  * Improved presigned urls with non standard base urls
* Sun Apr  5 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.7:
  * Removed accidentally left over debug print from previous release
- from v0.3.6
  * support adding default meta data
  * Also new settings: MINIO_STORAGE_MEDIA_OBJECT_METADATA and
    MINIO_STORAGE_STATIC_OBJECT_METADATA
  * fix issue with directory listing names
* Thu Jan  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.5:
  * Added settings MINIO_STORAGE_ASSUME_MEDIA_BUCKET_EXISTS and
    MINIO_STORAGE_ASSUME_STATIC_BUCKET_EXISTS
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.4:
  * Commandline interface redesign
  * Update for new django releases
  * Various test fixes
* Fri Mar 15 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite, disabled by default with bcond test as
  it depends on minio, not yet accepted into openSUSE.
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.2.2
